(window.webpackJsonp=window.webpackJsonp||[]).push([[17],{v2PB:function(e,t,r){"use strict";function n(e){var t={icon:"folder",id:"manage-folder",subTitle:"Manage folder dashboards & permissions",url:"",text:e.title,breadcrumbs:[{title:"Dashboards",url:"dashboards"}],children:[{active:!1,icon:"apps",id:"folder-dashboards-".concat(e.uid),text:"Dashboards",url:e.url}]};return e.canAdmin&&t.children.push({active:!1,icon:"lock",id:"folder-permissions-".concat(e.uid),text:"Permissions",url:"".concat(e.url,"/permissions")}),e.canSave&&t.children.push({active:!1,icon:"cog",id:"folder-settings-".concat(e.uid),text:"Settings",url:"".concat(e.url,"/settings")}),t}function a(e){var t=n({id:1,uid:"loading",title:"Loading",url:"url",canSave:!0,canEdit:!0,canAdmin:!0,version:0});return t.children[e].active=!0,{main:t,node:t.children[e]}}r.d(t,"a",(function(){return n})),r.d(t,"b",(function(){return a}))},zD1S:function(e,t,r){"use strict";r.r(t);var n=r("q1tI"),a=r.n(n),o=r("Y8YH"),i=r("/MKj"),c=r("Obii"),l=r("t8hP"),d=r("lzJ5"),u=r("X+V3"),s=r("ZGyg"),b=r("NXk7"),f=r("v2PB"),v=r("jbKi");function p(e,t){var r=Object.keys(e);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(e);t&&(n=n.filter((function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable}))),r.push.apply(r,n)}return r}function h(e){for(var t=1;t<arguments.length;t++){var r=null!=arguments[t]?arguments[t]:{};t%2?p(Object(r),!0).forEach((function(t){g(e,t,r[t])})):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(r)):p(Object(r)).forEach((function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(r,t))}))}return e}function g(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}r.d(t,"DashboardListPage",(function(){return O}));var O=Object(n.memo)((function(e){var t,r=e.navModel,n=e.uid,i=e.url,d=Object(o.a)((function(){return n&&i.startsWith("/dashboards")?function(e){return b.b.getFolderByUid(e).then((function(e){var t=Object(f.a)(e);return t.children[0].active=!0,{folder:e,folderNav:t}}))}(n).then((function(e){var t=e.folder,n=e.folderNav,a=c.locationUtil.stripBaseFromUrl(t.url);return a!==location.pathname&&Object(l.getLocationSrv)().update({path:a}),{folder:t,pageNavModel:h({},r,{main:n})}})):Promise.resolve({pageNavModel:r})}),[n]),u=d.loading,p=d.value;return a.a.createElement(s.a,{navModel:null!==(t=null==p?void 0:p.pageNavModel)&&void 0!==t?t:r},a.a.createElement(s.a.Contents,{isLoading:u},a.a.createElement(v.a,{folder:null==p?void 0:p.folder})))}));O.displayName="DashboardListPage";t.default=Object(i.connect)((function(e){return{navModel:Object(d.a)(e.navIndex,"manage-dashboards"),uid:Object(u.b)(e.location).uid,url:Object(u.e)(e.location)}}))(O)}}]);
//# sourceMappingURL=DashboardListPage.4cef41c9baecdb31736b.js.map