(window.webpackJsonp=window.webpackJsonp||[]).push([[23],{"5WMr":function(e,r,t){"use strict";t.r(r),t.d(r,"ErrorPage",(function(){return E}));var n=t("q1tI"),a=t.n(n),o=t("/MKj"),c=t("t8hP"),l=t("kDLi"),i=t("ZGyg"),u=t("lzJ5");function s(e){return(s="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e})(e)}function m(e,r){if(!(e instanceof r))throw new TypeError("Cannot call a class as a function")}function p(e,r){for(var t=0;t<r.length;t++){var n=r[t];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(e,n.key,n)}}function f(e,r){return!r||"object"!==s(r)&&"function"!=typeof r?function(e){if(void 0===e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}(e):r}function b(e){return(b=Object.setPrototypeOf?Object.getPrototypeOf:function(e){return e.__proto__||Object.getPrototypeOf(e)})(e)}function y(e,r){return(y=Object.setPrototypeOf||function(e,r){return e.__proto__=r,e})(e,r)}var E=function(e){function r(){return m(this,r),f(this,b(r).apply(this,arguments))}var t,n,o;return function(e,r){if("function"!=typeof r&&null!==r)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(r&&r.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),r&&y(e,r)}(r,e),t=r,(n=[{key:"render",value:function(){var e=this.props.navModel;return a.a.createElement(i.a,{navModel:e},a.a.createElement(i.a.Contents,null,a.a.createElement("div",{className:"page-container page-body"},a.a.createElement("div",{className:"panel-container error-container"},a.a.createElement("div",{className:"error-column graph-box"},a.a.createElement("div",{className:"error-row"},a.a.createElement("div",{className:"error-column error-space-between graph-percentage"},a.a.createElement("p",null,"100%"),a.a.createElement("p",null,"80%"),a.a.createElement("p",null,"60%"),a.a.createElement("p",null,"40%"),a.a.createElement("p",null,"20%"),a.a.createElement("p",null,"0%")),a.a.createElement("div",{className:"error-column image-box"},a.a.createElement("img",{src:"public/img/graph404.svg",width:"100%",alt:"graph"}),a.a.createElement("div",{className:"error-row error-space-between"},a.a.createElement("p",{className:"graph-text"},"Then"),a.a.createElement("p",{className:"graph-text"},"Now"))))),a.a.createElement("div",{className:"error-column info-box"},a.a.createElement("div",{className:"error-row current-box"},a.a.createElement("p",{className:"current-text"},"current")),a.a.createElement("div",{className:"error-row",style:{flex:1}},a.a.createElement(l.Icon,{name:"minus-circle",className:"error-minus"}),a.a.createElement("div",{className:"error-column error-space-between error-full-width"},a.a.createElement("div",{className:"error-row error-space-between"},a.a.createElement("p",null,"Chances you are on the page you are looking for."),a.a.createElement("p",{className:"left-margin"},"0%")),a.a.createElement("div",null,a.a.createElement("h3",null,"Sorry for the inconvenience"),a.a.createElement("p",null,"Please go back to your"," ",a.a.createElement("a",{href:c.config.appSubUrl,className:"error-link"},"home dashboard")," ","and try again."),a.a.createElement("p",null,"If the error persists, seek help on the"," ",a.a.createElement("a",{href:"https://community.grafana.com",target:"_blank",rel:"noreferrer",className:"error-link"},"community site"),".")))))))))}}])&&p(t.prototype,n),o&&p(t,o),r}(n.PureComponent);r.default=Object(o.connect)((function(e){return{navModel:Object(u.a)(e.navIndex,"not-found")}}))(E)}}]);
//# sourceMappingURL=ErrorPage.4cef41c9baecdb31736b.js.map