(window.webpackJsonp=window.webpackJsonp||[]).push([[91],{"cD+E":function(e,t,n){"use strict";n.r(t);var o=n("Obii");function r(e){return(r="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e})(e)}function u(e,t){for(var n=0;n<t.length;n++){var o=t[n];o.enumerable=o.enumerable||!1,o.configurable=!0,"value"in o&&(o.writable=!0),Object.defineProperty(e,o.key,o)}}function i(e,t){return!t||"object"!==r(t)&&"function"!=typeof t?function(e){if(void 0===e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}(e):t}function c(e){return(c=Object.setPrototypeOf?Object.getPrototypeOf:function(e){return e.__proto__||Object.getPrototypeOf(e)})(e)}function a(e,t){return(a=Object.setPrototypeOf||function(e,t){return e.__proto__=t,e})(e,t)}var f=function(e){function t(e){return function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,t),i(this,c(t).call(this,e))}var n,o,r;return function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),t&&a(e,t)}(t,e),n=t,(o=[{key:"getCollapsedText",value:function(e){return"Dashboard Reference: ".concat(e.panelId)}},{key:"query",value:function(e){return Promise.reject("This should not be called directly")}},{key:"testDatasource",value:function(){return Promise.resolve({})}}])&&u(n.prototype,o),r&&u(n,r),t}(o.DataSourceApi);n.d(t,"plugin",(function(){return l}));var l=new o.DataSourcePlugin(f)}}]);
//# sourceMappingURL=91.4cef41c9baecdb31736b.js.map