(window.webpackJsonp=window.webpackJsonp||[]).push([[96],{sDlW:function(e,n){ace.define("ace/snippets/json",["require","exports","module"],(function(e,n,s){"use strict";n.snippetText=void 0,n.scope="json"}))}}]);
//# sourceMappingURL=96.4cef41c9baecdb31736b.js.map